{ config, pkgs, nixpkgs, ... }:

{
  imports =
    [ 
      ./hardware-configuration.nix
      # Enable Nvidia driver and CUDA
      ./nvidia.nix
      # Set of Modules Defining System Configuration
      ./modules.nix
      # Set of system services, like ssh, and RDP/VNC
      ./services.nix
      # Public facing/outward facing servers (XPRA, Git(lab|ea))
      ./servers.nix
      # Set of System Wide Available Packages
      ./packages.nix
      # Set of Users on This System
      ./users.nix
      # Disable sleep (so SSH remains accessible)
      ./nosleep.nix
    ];

  # Support NTFS(3g)
  boot.supportedFilesystems = ["ntfs"];
  
  networking.firewall.enable = true;

  # Use the systemd-boot EFI boot loader.
  boot.loader.systemd-boot.enable = true;
  boot.loader.efi.canTouchEfiVariables = true;

  networking.hostName = "kcnhub";

  time.timeZone = "America/Toronto";

  # Enable the X11 windowing system.
  services.xserver.enable = true;

  # Enable KDE Plasma
  services.xserver.displayManager.sddm.enable = true;
  services.xserver.desktopManager.plasma5.enable = true;

  # Enable CUPS to print documents.
  services.printing.enable = true;

  # Enable sound.
  security.rtkit.enable = true;
  services.pipewire = {
    enable = true;
    alsa.enable = true;
    alsa.support32Bit = true;
    pulse.enable = true;
    jack.enable = true;
  };
  # Disable Pulseaudio -- we get its features through pipewire
  hardware.pulseaudio.enable = false;

  # TODO: Define module for adding users & their ssh keys & what projects they have in their home folder
  # Define a user account. Don't forget to set a password with ‘passwd’.
  # users.users.alice = {
  #   isNormalUser = true;
  #   extraGroups = [ "wheel" ]; # Enable ‘sudo’ for the user.
  #   packages = with pkgs; [
  #     firefox
  #     thunderbird
  #   ];
  # };

  # TODO: Make set of themed packages for packages that are available, e.g. Python packages, Matlab, Octave, etc.
  environment.systemPackages = with pkgs; [
    # Needed to manage Flake
    git
    # Needed to use secrets
    sops
    # Used for Key Generation
    age
  ];

  nix.registry.nixpkgs.flake = nixpkgs;
  
  # TODO: Make services directory for with a nix for each service that is enabled and what options it has
  # List services that you want to enable:

  # Enable the OpenSSH daemon.
  services.openssh.enable = true;

  # Open ports in the firewall.
  # networking.firewall.allowedTCPPorts = [ ... ];
  # networking.firewall.allowedUDPPorts = [ ... ];
  # Or disable the firewall altogether.
  # networking.firewall.enable = false;

  # Copy the NixOS configuration file and link it from the resulting system
  # (/run/current-system/configuration.nix). This is useful in case you
  # accidentally delete configuration.nix.
  # system.copySystemConfiguration = true;

  # This value determines the NixOS release from which the default
  # settings for stateful data, like file locations and database versions
  # on your system were taken. It‘s perfectly fine and recommended to leave
  # this value at the release version of the first install of this system.
  # Before changing this value read the documentation for this option
  # (e.g. man configuration.nix or on https://nixos.org/nixos/options.html).
  system.stateVersion = "22.11"; # Did you read the comment?
}

